'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var umi = require('@metaplex-foundation/umi');

class BundlrError extends umi.UmiError {
  name = 'BundlrError';
  constructor(message, cause) {
    super(message, 'plugin', 'Bundlr', cause);
  }
}
class FailedToInitializeBundlrError extends BundlrError {
  name = 'FailedToInitializeBundlrError';
  constructor(cause) {
    const message = 'Bundlr could not be initialized. ' + 'Please check the underlying error below for more details.';
    super(message, cause);
  }
}
class FailedToConnectToBundlrAddressError extends BundlrError {
  name = 'FailedToConnectToBundlrAddressError';
  constructor(address, cause) {
    const message = `Bundlr could not connect to the provided address [${address}]. ` + 'Please ensure the provided address is valid. Some valid addresses include: ' + '"https://node1.bundlr.network" for mainnet and "https://devnet.bundlr.network" for devnet';
    super(message, cause);
  }
}
class AssetUploadFailedError extends BundlrError {
  name = 'AssetUploadFailedError';
  constructor(status) {
    const message = `The asset could not be uploaded to the Bundlr network and ` + `returned the following status code [${status}].`;
    super(message);
  }
}
class BundlrWithdrawError extends BundlrError {
  name = 'BundlrWithdrawError';
  constructor(status) {
    const message = `The balance could not be withdrawn from the Bundlr network and ` + `returned the following status code [${status}].`;
    super(message);
  }
}

exports.AssetUploadFailedError = AssetUploadFailedError;
exports.BundlrError = BundlrError;
exports.BundlrWithdrawError = BundlrWithdrawError;
exports.FailedToConnectToBundlrAddressError = FailedToConnectToBundlrAddressError;
exports.FailedToInitializeBundlrError = FailedToInitializeBundlrError;
//# sourceMappingURL=errors.cjs.map
